@@ -39,6 +39,8 @@ class User(Base, Timestamp):
                  default=generate_uuid)
     access_token = Column(String(length=255))
     email = Column(String(length=255), unique=True, primary_key=True)
+    full_name = Column(String(length=255))
+    username = Column(String(length=255))
     workflows = relationship("Workflow", backref="user_")
 
     def __repr__(self):
@@ -83,7 +85,6 @@ class Workflow(Base, Timestamp):
 
     id_ = Column(UUIDType, primary_key=True)
     name = Column(String(255))
-    run_number = Column(Integer)
     status = Column(Enum(WorkflowStatus), default=WorkflowStatus.created)
     owner_id = Column(UUIDType, ForeignKey('user_.id_'))
     reana_specification = Column(JSONType)
@@ -105,6 +106,9 @@ class Workflow(Base, Timestamp):
     #  jobs_finished = {job_ids: [], total: c}
     #  jobs_failed = {job_ids: [], total: c}}
     engine_specific = Column(JSONType)
+    git_ref = Column(String(40))
+    git_repo = Column(String(255))
+    git_provider = Column(String(255))
 
     __table_args__ = UniqueConstraint('name', 'owner_id', 'run_number',
                                       name='_user_workflow_run_uc'),
@@ -121,7 +125,10 @@ class Workflow(Base, Timestamp):
                  interactive_session_type=None,
                  input_parameters={},
                  operational_options={},
-                 status=WorkflowStatus.created):
+                 status=WorkflowStatus.created,
+                 git_ref='',
+                 git_repo=None,
+                 git_provider=None):
         """Initialize workflow model."""
         self.id_ = id_
         self.name = name
@@ -135,6 +142,9 @@ class Workflow(Base, Timestamp):
         self.interactive_session = interactive_session
         self.interactive_session_name = interactive_session_name
         self.interactive_session_type = interactive_session_type
+        self.git_ref = git_ref
+        self.git_repo = git_repo
+        self.git_provider = git_provider
         from .database import Session
         last_workflow = Session.query(Workflow).filter_by(
             name=name,
@@ -172,6 +182,10 @@ class Workflow(Base, Timestamp):
             id_=self.owner_id).first()
         return owner.access_token
 
+    def get_full_workflow_name(self):
+        """Return full workflow name including run number."""
+        return "{}.{}".format(self.name, self.run_number)
+
     @staticmethod
     def update_workflow_status(db_session, workflow_uuid, status,
                                new_logs='', message=None):
@@ -208,18 +222,16 @@ class Job(Base, Timestamp):
     backend_job_id = Column(String(256))
     workflow_uuid = Column(UUIDType)
     status = Column(Enum(JobStatus), default=JobStatus.created)
-    backend = Column(String(30))
+    compute_backend = Column(String(30))
     cvmfs_mounts = Column(Text)
     shared_file_system = Column(Boolean)
     docker_img = Column(String(256))
     cmd = Column(JSONType)
     env_vars = Column(JSONType)
-    restart_count = Column(Integer)
-    max_restart_count = Column(Integer)
     deleted = Column(Boolean)
     logs = Column(String, nullable=True)
     prettified_cmd = Column(JSONType)
-    name = Column(Text)
+    job_name = Column(Text)
 
 
 class JobCache(Base, Timestamp):
